@@ -1,3 +1,4 @@
+from typing import Optional, Union
 import hashlib
 import json
 import pathlib
@@ -35,10 +36,16 @@ def _get_batch_signed_urls(figure_url: str, files_batch: list, api_key: str) ->
     payload = {
         "figureUrl": figure_url,
         "files": files_data,
-        "apiKey": api_key,
     }
 
-    response = requests.post(f"{FIGPACK_API_BASE_URL}/api/upload", json=payload)
+    headers = {
+        "Content-Type": "application/json",
+        "x-api-key": api_key if api_key else "",
+    }
+
+    response = requests.post(
+        f"{FIGPACK_API_BASE_URL}/upload", json=payload, headers=headers
+    )
 
     if not response.ok:
         try:
@@ -114,57 +121,24 @@ def _upload_single_file_with_signed_url(
         else:
             break
 
+    assert last_exception is not None
     raise last_exception
 
 
 MAX_WORKERS_FOR_UPLOAD = 16
 
 
-def _compute_deterministic_figure_hash(tmpdir_path: pathlib.Path) -> str:
-    """
-    Compute a deterministic figure ID based on SHA1 hashes of all files
-
-    Returns:
-        str: 40-character SHA1 hash representing the content of all files
-    """
-    file_hashes = []
-
-    # Collect all files and their hashes
-    for file_path in sorted(tmpdir_path.rglob("*")):
-        if file_path.is_file():
-            relative_path = file_path.relative_to(tmpdir_path)
-
-            # Compute SHA1 hash of file content
-            sha1_hash = hashlib.sha1()
-            with open(file_path, "rb") as f:
-                for chunk in iter(lambda: f.read(4096), b""):
-                    sha1_hash.update(chunk)
-
-            # Include both the relative path and content hash to ensure uniqueness
-            file_info = f"{relative_path}:{sha1_hash.hexdigest()}"
-            file_hashes.append(file_info)
-
-    # Create final hash from all file hashes
-    combined_hash = hashlib.sha1()
-    for file_hash in file_hashes:
-        combined_hash.update(file_hash.encode("utf-8"))
-
-    return combined_hash.hexdigest()
-
-
 def _create_or_get_figure(
-    figure_hash: str,
-    api_key: str,
-    total_files: int = None,
-    total_size: int = None,
-    title: str = None,
+    api_key: Optional[str],
+    total_files: Optional[int] = None,
+    total_size: Optional[int] = None,
+    title: Optional[str] = None,
     ephemeral: bool = False,
 ) -> dict:
     """
     Create a new figure or get existing figure information
 
     Args:
-        figure_hash: The hash of the figure
         api_key: The API key for authentication (required for non-ephemeral)
         total_files: Optional total number of files
         total_size: Optional total size of files
@@ -178,15 +152,14 @@ def _create_or_get_figure(
     if not ephemeral and api_key is None:
         raise ValueError("API key is required for non-ephemeral figures")
 
-    payload = {
-        "figureHash": figure_hash,
+    payload: dict[str, Union[str, int]] = {
         "figpackVersion": __version__,
         "bucket": FIGPACK_BUCKET,
     }
 
     # API key is optional for ephemeral figures
-    if api_key is not None:
-        payload["apiKey"] = api_key
+    # if api_key is not None:
+    #     payload["apiKey"] = api_key
 
     if total_files is not None:
         payload["totalFiles"] = total_files
@@ -198,7 +171,12 @@ def _create_or_get_figure(
         payload["ephemeral"] = True
 
     # Use the same endpoint for both regular and ephemeral figures
-    response = requests.post(f"{FIGPACK_API_BASE_URL}/api/figures/create", json=payload)
+    url = f"{FIGPACK_API_BASE_URL}/figures/create"
+    headers = {
+        "Content-Type": "application/json",
+        "x-api-key": api_key if api_key else "",
+    }
+    response = requests.post(url, json=payload, headers=headers)
 
     if not response.ok:
         try:
@@ -206,12 +184,12 @@ def _create_or_get_figure(
             error_msg = error_data.get("message", "Unknown error")
         except:
             error_msg = f"HTTP {response.status_code}"
-        raise Exception(f"Failed to create figure {figure_hash}: {error_msg}")
+        raise Exception(f"Failed to create figure: {error_msg}")
 
     response_data = response.json()
     if not response_data.get("success"):
         raise Exception(
-            f"Failed to create figure {figure_hash}: {response_data.get('message', 'Unknown error')}"
+            f"Failed to create figure: {response_data.get('message', 'Unknown error')}"
         )
 
     return response_data
@@ -226,11 +204,15 @@ def _finalize_figure(figure_url: str, api_key: str) -> dict:
     """
     payload = {
         "figureUrl": figure_url,
-        "apiKey": api_key,
+    }
+
+    headers = {
+        "Content-Type": "application/json",
+        "x-api-key": api_key if api_key else "",
     }
 
     response = requests.post(
-        f"{FIGPACK_API_BASE_URL}/api/figures/finalize", json=payload
+        f"{FIGPACK_API_BASE_URL}/figures/finalize", json=payload, headers=headers
     )
 
     if not response.ok:
@@ -252,8 +234,8 @@ def _finalize_figure(figure_url: str, api_key: str) -> dict:
 
 def _upload_bundle(
     tmpdir: str,
-    api_key: str,
-    title: str = None,
+    api_key: Optional[str],
+    title: Optional[str] = None,
     ephemeral: bool = False,
     use_consolidated_metadata_only: bool = False,
 ) -> str:
@@ -270,9 +252,6 @@ def _upload_bundle(
     """
     tmpdir_path = pathlib.Path(tmpdir)
 
-    # Compute deterministic figure ID based on file contents
-    figure_hash = _compute_deterministic_figure_hash(tmpdir_path)
-
     # Collect all files to upload
     all_files = []
     for file_path in tmpdir_path.rglob("*"):
@@ -293,7 +272,11 @@ def _upload_bundle(
 
     # Find available figure ID and create/get figure in database with metadata
     result = _create_or_get_figure(
-        figure_hash, api_key, total_files, total_size, title=title, ephemeral=ephemeral
+        api_key,
+        total_files,
+        total_size,
+        title=title,
+        ephemeral=ephemeral,
     )
     figure_info = result.get("figure", {})
     figure_url = figure_info.get("figureUrl")
@@ -329,7 +312,9 @@ def _upload_bundle(
 
             # Get signed URLs for this batch
             try:
-                signed_urls_map = _get_batch_signed_urls(figure_url, batch, api_key)
+                signed_urls_map = _get_batch_signed_urls(
+                    figure_url, batch, api_key if api_key else ""
+                )
             except Exception as e:
                 print(f"Failed to get signed URLs for batch {batch_num}: {e}")
                 raise
@@ -400,7 +385,9 @@ def _upload_bundle(
     try:
         # Use batch API for manifest
         manifest_batch = [("manifest.json", temp_file_path)]
-        signed_urls_map = _get_batch_signed_urls(figure_url, manifest_batch, api_key)
+        signed_urls_map = _get_batch_signed_urls(
+            figure_url, manifest_batch, api_key if api_key else ""
+        )
 
         if "manifest.json" not in signed_urls_map:
             raise Exception("No signed URL returned for manifest.json")
@@ -418,7 +405,7 @@ def _upload_bundle(
 
     # Finalize the figure upload
     print("Finalizing figure...")
-    _finalize_figure(figure_url, api_key)
+    _finalize_figure(figure_url, api_key if api_key else "")
     print("Upload completed successfully")
 
     return figure_url
