@@ -2,9 +2,13 @@
 Base class for views that use figpack extensions
 """
 
+from typing import TYPE_CHECKING
+
 from .figpack_view import FigpackView
-from .figpack_extension import FigpackExtension
-from ..core.zarr import Group
+
+if TYPE_CHECKING:
+    from .figpack_extension import FigpackExtension
+    from .zarr import Group
 
 
 class ExtensionView(FigpackView):
@@ -12,7 +16,7 @@ class ExtensionView(FigpackView):
     Base class for views that are rendered by figpack extensions
     """
 
-    def __init__(self, *, extension: FigpackExtension, view_type: str):
+    def __init__(self, *, extension: "FigpackExtension", view_type: str) -> None:
         """
         Initialize an extension-based view
 
@@ -23,7 +27,7 @@ class ExtensionView(FigpackView):
         self.extension = extension
         self.view_type = view_type
 
-    def write_to_zarr_group(self, group: Group) -> None:
+    def write_to_zarr_group(self, group: "Group") -> None:
         """
         Write the extension view metadata to a Zarr group.
         Subclasses should call super().write_to_zarr_group(group) first,
