@@ -4,7 +4,6 @@ import pytest
 import requests
 
 from figpack.core._upload_bundle import (
-    _compute_deterministic_figure_hash,
     _create_or_get_figure,
     _determine_content_type,
     _finalize_figure,
@@ -50,7 +49,6 @@ def test_get_batch_signed_urls(tmp_path):
         called_payload = mock_post.call_args[1]["json"]
         assert "upload" in called_url
         assert called_payload["figureUrl"] == figure_url
-        assert called_payload["apiKey"] == api_key
         assert len(called_payload["files"]) == 2
 
 
@@ -120,29 +118,7 @@ def test_upload_single_file_with_retry(tmp_path):
         assert mock_put.call_count == 2
 
 
-def test_compute_deterministic_figure_hash(tmp_path):
-    # Create test files with known content
-    file1 = tmp_path / "file1.txt"
-    file2 = tmp_path / "file2.txt"
-    file1.write_text("content1")
-    file2.write_text("content2")
-
-    hash1 = _compute_deterministic_figure_hash(tmp_path)
-    assert isinstance(hash1, str)
-    assert len(hash1) == 40  # SHA1 hash is 40 characters
-
-    # Same content should produce same hash
-    hash2 = _compute_deterministic_figure_hash(tmp_path)
-    assert hash1 == hash2
-
-    # Different content should produce different hash
-    file1.write_text("different content")
-    hash3 = _compute_deterministic_figure_hash(tmp_path)
-    assert hash1 != hash3
-
-
 def test_create_or_get_figure():
-    figure_hash = "test-hash"
     api_key = "test-key"
 
     mock_response = mock.Mock()
@@ -154,15 +130,13 @@ def test_create_or_get_figure():
 
     with mock.patch("requests.post") as mock_post:
         mock_post.return_value = mock_response
-        result = _create_or_get_figure(figure_hash, api_key)
+        result = _create_or_get_figure(api_key)
 
         assert result["success"]
         assert result["figure"]["figureUrl"] == "test-url"
         assert result["figure"]["status"] == "pending"
 
         mock_post.assert_called_once()
-        assert mock_post.call_args[1]["json"]["figureHash"] == figure_hash
-        assert mock_post.call_args[1]["json"]["apiKey"] == api_key
 
 
 def test_create_or_get_figure_error():
@@ -194,7 +168,6 @@ def test_finalize_figure():
 
         mock_post.assert_called_once()
         assert mock_post.call_args[1]["json"]["figureUrl"] == figure_url
-        assert mock_post.call_args[1]["json"]["apiKey"] == api_key
 
 
 def test_determine_content_type():
